@@ -1,6 +1,6 @@
 from sqlalchemy.orm.properties import ColumnProperty
 from sqlalchemy.sql import expression
-from sqlalchemy.sql.expression import ColumnClause
+from sqlalchemy.sql.expression import ColumnClause, literal
 from sqlalchemy.types import TypeEngine
 from sqlalchemy.ext.compiler import compiles
 
@@ -115,6 +115,13 @@ class DBSpatialElement(SpatialElement, expression.Function):
         self.desc = desc
         expression.Function.__init__(self, "", desc)
 
+@compiles(DBSpatialElement)
+def __compile_dbspatialelement(element, compiler, **kw):
+    function = _get_function(element, compiler, [literal(element.desc)], 
+                                        kw.get('within_columns_clause', False))
+    
+    return compiler.process(function)
+
 class PersistentSpatialElement(SpatialElement):
     """Represents a Geometry value loaded from the database."""
     
@@ -165,6 +172,11 @@ class GeometryBase(TypeEngine):
             else:
                 return value
         return process
+    
+    def _compiler_dispatch(self, *args):
+        """Required for the Cast() operator when used for the compilation
+        of DBSpatialElement"""
+        return self.name
 
 # ORM integration
 
@@ -232,7 +244,7 @@ class SpatialComparator(ColumnProperty.ColumnComparator):
             session.query(func.extent(Spot.spot_location.RAW)).first() 
         
         """
-        return RawColumn(self.property.columns[0])
+        return RawColumn(self.__clause_element__())
     
     def __getattr__(self, name):
         return getattr(functions, name)(self)
