@@ -2,8 +2,11 @@ from sqlalchemy.dialects.postgresql.base import PGDialect
 from sqlalchemy.dialects.sqlite.base import SQLiteDialect
 from sqlalchemy.dialects.mysql.base import MySQLDialect
 from sqlalchemy.dialects.oracle.base import OracleDialect
+from sqlalchemy.dialects.mssql.base import MSDialect
+from sqlalchemy import func
 from geoalchemy.functions import functions
-from geoalchemy.base import WKTSpatialElement, WKBSpatialElement
+from geoalchemy.base import WKTSpatialElement, WKBSpatialElement,\
+    DBSpatialElement
 
 class SpatialDialect(object):
     """This class bundles all required classes and methods to support 
@@ -18,9 +21,11 @@ class SpatialDialect(object):
                    WKTSpatialElement : 'GeomFromText',
                    functions.wkb: 'AsBinary',
                    WKBSpatialElement : 'GeomFromWKB',
+                   DBSpatialElement : '',
                    functions.dimension : 'Dimension',
                    functions.srid : 'SRID',
                    functions.geometry_type : 'GeometryType',
+                   functions.is_valid : 'IsValid',
                    functions.is_empty : 'IsEmpty',
                    functions.is_simple : 'IsSimple',
                    functions.is_closed : 'IsClosed',
@@ -51,7 +56,9 @@ class SpatialDialect(object):
                    functions.gcontains : 'Contains',
                    functions.covers : 'Covers',
                    functions.covered_by : 'CoveredBy',
-                   functions.intersection : 'Intersections'
+                   functions.intersection : 'Intersections',
+                   functions._within_distance: lambda compiler, geom1, geom2, dist:
+                                                   func.DWithin(geom1, geom2, dist)
                   }
     
     def get_function(self, function_class):
@@ -94,6 +101,16 @@ class SpatialDialect(object):
         """
         return False
     
+    def is_property(self, function_class):   
+        """Returns True if the passed-in function should be called as property, 
+        e.g.::
+        
+            Point.the_geom.x is compiled as (for MS Server):
+            points.the_geom.x
+            
+        """
+        return False
+    
     def _get_function_mapping(self):
         """This method can be overridden in subclasses, to set a database specific name
         for a function, or to add new functions, that are only supported by the database.
@@ -162,12 +179,14 @@ class DialectManager(object):
         from geoalchemy.mysql import MySQLSpatialDialect
         from geoalchemy.spatialite import SQLiteSpatialDialect
         from geoalchemy.oracle import OracleSpatialDialect
+        from geoalchemy.mssql import MSSpatialDialect
             
         DialectManager.__dialects_mapping = {
                 PGDialect: PGSpatialDialect,
                 SQLiteDialect: SQLiteSpatialDialect,
                 MySQLDialect: MySQLSpatialDialect,
-                OracleDialect: OracleSpatialDialect
+                OracleDialect: OracleSpatialDialect,
+                MSDialect: MSSpatialDialect
                 }
 
     @staticmethod
@@ -198,4 +217,4 @@ class DialectManager(object):
             return DialectManager.__spatial_dialect_instances[spatial_dialect]
         else:
             raise NotImplementedError('Dialect "%s" is not supported by GeoAlchemy' % (dialect.name))
-        
\ No newline at end of file
+        
