@@ -5,6 +5,7 @@ from geoalchemy.base import SpatialComparator, PersistentSpatialElement,\
 from geoalchemy.dialect import SpatialDialect 
 from geoalchemy.functions import functions, BaseFunction
 from geoalchemy.mysql import mysql_functions
+from geoalchemy.geometry import GeometryExtensionColumn
 
 
 class SQLiteComparator(SpatialComparator):
@@ -41,10 +42,28 @@ class sqlite_functions(mysql_functions):
     class fgf(BaseFunction):
         """AsFGF(g)"""
         pass
-    
-    class is_valid(BaseFunction):
-        """IsValid(g)"""
-        pass
+
+    @staticmethod
+    def _within_distance(compiler, geom1, geom2, distance, *args):
+        if isinstance(geom1, GeometryExtensionColumn) and \
+           geom1.type.spatial_index and \
+           SQLiteSpatialDialect.supports_rtree(compiler.dialect):
+            """If querying on a geometry column that also has a spatial index,
+            then make use of this index.
+
+            see: http://www.gaia-gis.it/spatialite/spatialite-tutorial-2.3.1.html#t8 and
+            http://groups.google.com/group/spatialite-users/browse_thread/thread/34609c7a711ac92d/7688ced3f909039c?lnk=gst&q=index#f6dbc235471574db
+            """
+            return and_(
+                func.Distance(geom1, geom2) <= distance,
+                table(geom1.table.fullname, column("rowid")).c.rowid.in_(
+                    select([table("idx_%s_%s" % (geom1.table.fullname, geom1.key), column("pkid")).c.pkid]).where(
+                        and_(text('xmin') >= func.MbrMinX(geom2) - distance,
+                        and_(text('xmax') <= func.MbrMaxX(geom2) + distance,
+                        and_(text('ymin') >= func.MbrMinY(geom2) - distance,
+                             text('ymax') <= func.MbrMaxY(geom2) + distance))))))
+        else:
+            return func.Distance(geom1, geom2) <= distance
 
 
 class SQLiteSpatialDialect(SpatialDialect):
@@ -55,14 +74,14 @@ class SQLiteSpatialDialect(SpatialDialect):
                    functions.length : 'GLength',
                    sqlite_functions.svg : 'AsSVG',
                    sqlite_functions.fgf : 'AsFGF',
-                   sqlite_functions.is_valid : 'IsValid',
                    mysql_functions.mbr_equal : 'MBREqual',
                    mysql_functions.mbr_disjoint : 'MBRDisjoint',
                    mysql_functions.mbr_intersects : 'MBRIntersects',
                    mysql_functions.mbr_touches : 'MBRTouches',
                    mysql_functions.mbr_within : 'MBRWithin',
                    mysql_functions.mbr_overlaps : 'MBROverlaps',
-                   mysql_functions.mbr_contains : 'MBRContains'
+                   mysql_functions.mbr_contains : 'MBRContains',
+                   functions._within_distance : sqlite_functions._within_distance
                    }
 
     def _get_function_mapping(self):
